==> haskell-path-pieces-0.2.1-11-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-path-pieces.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: path-pieces
version: 0.2.1
id: path-pieces-0.2.1-N9A0XE9UWV4ET35XMVEmE
key: path-pieces-0.2.1-N9A0XE9UWV4ET35XMVEmE
license: BSD3
maintainer: Michael Snoyman <michael@snoyman.com>
stability: unstable
synopsis: Components of paths.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/path-pieces>.
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
indefinite: False
exposed-modules:
    Web.PathPieces
abi: 18b436f968531156bf10655851d6c559
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/path-pieces-0.2.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/path-pieces-0.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/path-pieces-0.2.1
hs-libraries: HSpath-pieces-0.2.1-N9A0XE9UWV4ET35XMVEmE
depends:
    base-4.10.1.0 text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj time-1.8.0.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
haddock-interfaces: /usr/share/doc/haskell-path-pieces/html/path-pieces.haddock
haddock-html: /usr/share/doc/haskell-path-pieces/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-path-pieces-0.2.1-12-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-path-pieces.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: path-pieces
version: 0.2.1
id: path-pieces-0.2.1-BbZOveR2lVe9KIkwmleWEu
key: path-pieces-0.2.1-BbZOveR2lVe9KIkwmleWEu
license: BSD3
maintainer: Michael Snoyman <michael@snoyman.com>
stability: unstable
synopsis: Components of paths.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/path-pieces>.
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
indefinite: False
exposed-modules:
    Web.PathPieces
abi: 836d2f307ab364d7fb9bc7fb26b0e5fe
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/path-pieces-0.2.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/path-pieces-0.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/path-pieces-0.2.1
hs-libraries: HSpath-pieces-0.2.1-BbZOveR2lVe9KIkwmleWEu
depends:
    base-4.10.1.0 text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz time-1.8.0.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
haddock-interfaces: /usr/share/doc/haskell-path-pieces/html/path-pieces.haddock
haddock-html: /usr/share/doc/haskell-path-pieces/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
